pub struct InvalidBits<Base: Unsigned>(pub Base);Expand description
Represents an invalid bit pattern for a field with a custom representation.
This is returned as the error type for the getters of such fields.
Tuple Fields
0: Basepub struct InvalidBits<Base: Unsigned>(pub Base);Represents an invalid bit pattern for a field with a custom representation.
This is returned as the error type for the getters of such fields.
0: Base