pub trait Unsigned: Debug + Sealed { }Expand description
Implemented by unsigned integral type, this trait represents a valid base type for a bitfield layout.
pub trait Unsigned: Debug + Sealed { }Implemented by unsigned integral type, this trait represents a valid base type for a bitfield layout.